# Client for pokerserver.py

import subprocess
import platform
import sys
import os.path
import renpy

stdout = file("poker-stdout.txt", "wb", 0)
stderr = file("poker-stderr.txt", "wb", 0)

def command(name, **kwargs):
    """
    This passes the named command to the server, which evaluates
    it. This then evaluates the result of the command, and returns
    that.
    """

    command = "%s(**%r)\n\n" % (name, kwargs)
    server.stdin.write(command)
    server.stdin.flush()

    result = ""

    while True:
        l = server.stdout.readline()

        stdout.write(l)

        if result.strip() and not l.strip():
            break

        result += l
        
    result = result.replace("\r", " ")
    result = result.replace("\n", " ")

    return eval(result)

# These functions proxy for the equivalent methods on PokerEval.

def winners(**kwargs):
    return command("winners", **kwargs)

def poker_eval(**kwargs):
    return command("poker_eval", **kwargs)

def best_hand(**kwargs):
    return command("best_hand", **kwargs)

def strength_potential(pocket, board):
    return command("strength_potential", pocket=pocket, board=board)

def version():
    return command("version")

basedir = os.path.abspath(renpy.config.basedir)

if sys.platform == 'win32':

    CREATE_NO_WINDOW=0x08000000

    print >>stdout, "WINDOWS", basedir + "/poker-engine/pokerserver.exe"
    
    # The connection to the poker server process.
    server = subprocess.Popen(
        [ basedir + "/poker-engine/pokerserver.exe"],
        stdin=subprocess.PIPE,
        stdout=subprocess.PIPE,
        stderr=stderr,
        creationflags=CREATE_NO_WINDOW)

else:

    print >>stdout, "OTHER", basedir + "/poker-engine/pokerserver.py"

    # The connection to the poker server process.
    server = subprocess.Popen(
        [ sys.executable, basedir + "/poker-engine/pokerserver.py"],
        stdin=subprocess.PIPE,
        stdout=subprocess.PIPE,
        stderr=stderr)

version()
version()
